#
# spec file
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}

%global pname gflags

%if "%{flavor}" == "static"
%define psuffix -%{flavor}
%bcond_with    build_shared
%bcond_without build_static
%else
%define psuffix %{nil}
%bcond_without build_shared
%bcond_with    build_static
%endif

%define soversion 2_2

Name:           gflags%{psuffix}
Version:        2.2.2
Release:        4.5
Summary:        Library for commandline flag processing
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/gflags/gflags
Source0:        https://github.com/%{pname}/%{pname}/archive/v%{version}.tar.gz#/%{pname}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
Requires:       libgflags%{soversion} = %{version}

%description
The gflags package contains a library that implements commandline
flags processing. As such, it is a replacement for getopt(). It has
increased flexibility, including built-in support for C++ types like
string, and the ability to define flags in the source file in which
they're used.

%package -n libgflags%{soversion}
Summary:        Library for commandline flag processing
Conflicts:      libgflags2

%description -n libgflags%{soversion}
The gflags package contains a library that implements commandline
flags processing. As such, it is a replacement for getopt(). It has
increased flexibility, including built-in support for C++ types like
string, and the ability to define flags in the source file in which
they're used.

%package devel
Summary:        Development files for the dynamic gflags library
Requires:       libgflags%{soversion} = %{version}

%description devel
This package contains all necessary include files and the dynamic libraries
needed for developing applications.

%package -n gflags-devel-static
Summary:        Development files for the static gflags library
# CMake config for static and shared differ, but use the same export file name
Conflicts:      %{pname}-devel

%description -n gflags-devel-static
This package contains all necessary include files and the static libraries
needed for developing applications.

%prep
%autosetup -n gflags-%{version}
# Fix prefix duplication, _libdir is absolute
sed -i -e 's@libdir=.*@libdir=%{_libdir}@' cmake/package.pc.in

%build
%if %{with build_static}
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%endif
%cmake \
    -DBUILD_STATIC_LIBS:BOOL=%{?with_build_static:ON}%{!?with_build_static:OFF} \
    -DBUILD_SHARED_LIBS:BOOL=%{?with_build_shared:ON}%{!?with_build_shared:OFF} \
    -DBUILD_TESTING:BOOL=ON \
    %{nil}

%cmake_build

%install
%cmake_install

%if "%{flavor}" == "static"
rm %{buildroot}%{_bindir}/%{pname}_completions.sh
mv %{buildroot}%{_libdir}/pkgconfig/%{pname}{,_static}.pc
%endif

# Installs a file on $HOME, remove it
rm -rf %{buildroot}/home/

%check
export LD_LIBRARY_PATH=`pwd`/%{__builddir}/lib
%ctest

%post -n libgflags%{soversion} -p /sbin/ldconfig
%postun -n libgflags%{soversion} -p /sbin/ldconfig

%if "%{flavor}" == ""
%files
%license COPYING.txt
%doc AUTHORS.txt ChangeLog.txt README.md
%{_bindir}/%{pname}_completions.sh

%files -n libgflags%{soversion}
%license COPYING.txt
%{_libdir}/libgflags.so.*
%{_libdir}/libgflags_nothreads.so.*

%files devel
%{_includedir}/%{pname}/
%{_libdir}/libgflags.so
%{_libdir}/libgflags_nothreads.so
%{_libdir}/cmake/%{pname}/
%{_libdir}/pkgconfig/%{pname}.pc
%endif

%if "%{flavor}" == "static"
%files -n gflags-devel-static
%{_includedir}/%{pname}/
%{_libdir}/cmake/%{pname}/
%{_libdir}/pkgconfig/%{pname}_static.pc
%{_libdir}/libgflags.a
%{_libdir}/libgflags_nothreads.a
%endif

%changelog
* Sat Aug 17 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Revert previous, incorrect change. gflags_shared is a CMake
  target name, not a filename. Unfortunately no context was
  provided, making it impossible to know what was actually
  wanted.
* Mon Jul 29 2024 Christian Goll <cgoll@suse.com>
- cmake include files want to link agains gflags_shared instead
  of glflags only. Creating this libs the hard way.
* Sun Aug 28 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix (uncritical) libdir error in pkgconfig file.
- Use default RelWithDebInfo build type.
- Use separate _multibuilds for static and dynamic libraries,
  otherwise CMake config depends on the static library.
* Wed Apr 27 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve rpmlint report "libgflags2.x86_64: E:
  shlib-policy-name-error SONAME: libgflags.so.2.2, expected
  package suffix: 2_2"
* Sun Aug  9 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to version 2.2.2
  * Fixed 267: Support build with GCC option "-fvisibility=hidden".
  * Fixed 262: Declare FALGS_no##name variables as static to avoid
    "previous extern" warning.
  * Fixed 261: Declare FlagRegisterer c’tor explicit template instanations as
    extern in header
  * Fixed 257: Build with _UNICODE support on Windows.
  * Fixed 233/234/235: Move CMake defines that are unused by Bazel to
    separate header; makes config.h private again
  * Fixed 228: Build with recent MinGW versions that define setenv.
  * Fixed 226: Remove obsolete and unused CleanFileName code
  * Merged 266: Various PVS Studio and GCC warnings.
  * Merged 258: Fix build with some Clang variants that define "restrict"
    macro.
  * Merged 252: Update documentation on how to use Bazel.
  * Merged 249: Use "_debug" postfix for debug libraries.
  * Merged 247: CMake "project" VERSION; no enable_testing(); "gflags::"
    import target prefix.
  * Merged 246: Add Bazel-on-Windows support.
  * Merged 239: Use GFLAGS_NAMESPACE instead of "gflags" in test executable.
  * Merged 237: Removed unused functions; fixes compilation with -Werror
    compiler option.
  * Merged 232: Fix typo in Bazel's BUILD definition
  * Merged 230: Remove using ::fLS::clstring.
  * Merged 221: Add convenience 'uninstall' target
- Run spec-cleaner
  * Remove package groups
  * Use make macros
* Tue Sep 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use -ffat-lto-objects when building static libraries.
* Tue Oct 30 2018 Jan Engelhardt <jengelh@inai.de>
- Add RPM groups. Fix wrong devel-static description.
* Tue Jul 11 2017 aloisio@gmx.com
- Update to version 2.2.1
  * Link to online documentation in README
  * Merged 194: Include utils by file instead of CMAKE_MODULE_PATH
    search
  * Merged 195: Remove unused program_name variable
  * Merged 196: Enable language C for older CMake versions when
    needed
  * Merged 202: Changed include directory in bazel build
  * Merged 207: Mark single argument constructors in mutex.h as
    explicit
  * Merged 215: Fix static initialization order fiasco caused by
    global registry lock
  * Merged 216: Fix use of ARGC in CMake macros
  * Merged 222: Static code analyzer error regarding strncmp with
    empty kRootDir
- Renamed source file
* Tue Mar 21 2017 miukumac@outlook.com
- Initial 2.2.0 release
